==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescription } from "./PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescription";
/**
 * @hidden
 */
var PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata, _super);
    function PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.b = function (a) {
        if (PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.a == null) {
            PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.c(PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.a);
        }
        if (a.k(PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.a);
    };
    PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.c = function (a) {
        a.item("TargetRef", "(w:Target,wf:Target)DataRef");
        a.item("ValueRef", "(w:Value,wf:Value)DataRef");
        a.item("PropertyPath", "String");
    };
    PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.d = function (a) {
        PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.b(a);
        a.ac("PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgs", function () { return new PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescription(); });
        a.ab("PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgs", PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.a);
    };
    PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.$t = markType(PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata, 'PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata');
    PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.a = null;
    return PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata;
}(Base));
export { PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescription } from "./PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescription";
/**
 * @hidden
 */
var PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata, _super);
    function PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.b = function (a) {
        if (PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.a == null) {
            PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.c(PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.a);
        }
        if (a.k(PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.a);
    };
    PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.c = function (a) {
        a.item("TargetRef", "(w:Target,wf:Target)DataRef");
        a.item("ValueRef", "(w:Value,wf:Value)DataRef");
        a.item("PropertyPath", "String");
    };
    PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.d = function (a) {
        PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.b(a);
        a.ae("PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgs", function () { return new PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescription(); });
        a.ad("PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgs", PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.a);
    };
    PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.$t = markType(PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata, 'PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata');
    PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.a = null;
    return PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata;
}(Base));
export { PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata };
